==> jc-1.4.0.tar.gz: soot/shimple/internal/analysis/GuaranteedDefs.h <==
// public class soot.shimple.internal.analysis.GuaranteedDefs

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2e0f053b55f5cb0d soot_shimple_internal_analysis_GuaranteedDefs

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_analysis_GuaranteedDefs_H_
#define _JC_soot_shimple_internal_analysis_GuaranteedDefs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$refs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$refs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object	_jc_soot_shimple_internal_analysis_GuaranteedDefs$object;

typedef const struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods;
typedef const struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable;
typedef const struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype;

// Constructors
extern void _jc_soot_shimple_internal_analysis_GuaranteedDefs$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_internal_analysis_GuaranteedDefs$method$getGuaranteedDefs$68ecc6b5537a17ad(_jc_env *, struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_analysis_GuaranteedDefs$method_info$getGuaranteedDefs$68ecc6b5537a17ad;

// Virtual methods structure
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods {
	struct _jc_object	*(*getGuaranteedDefs$68ecc6b5537a17ad)(_jc_env *, struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods	soot_shimple_internal_analysis_GuaranteedDefs;
};

// Vtype
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs {
	struct _jc_object	*unitToGuaranteedDefs;
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$refs {
    _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs	soot_shimple_internal_analysis_GuaranteedDefs;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs	soot_shimple_internal_analysis_GuaranteedDefs;
};

// Object instance structure
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object {
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype	*vtype;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype _jc_soot_shimple_internal_analysis_GuaranteedDefs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_analysis_GuaranteedDefs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_analysis_GuaranteedDefs$class_object;

#endif	/* _JC_soot_shimple_internal_analysis_GuaranteedDefs_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/internal/analysis/GuaranteedDefs.h <==
// public class soot.shimple.internal.analysis.GuaranteedDefs

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2e0f053b55f5cb0d soot_shimple_internal_analysis_GuaranteedDefs

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_analysis_GuaranteedDefs_H_
#define _JC_soot_shimple_internal_analysis_GuaranteedDefs_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$refs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$refs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs	_jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object	_jc_soot_shimple_internal_analysis_GuaranteedDefs$object;

typedef const struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods;
typedef const struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable;
typedef const struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype;

// Constructors
extern void _jc_soot_shimple_internal_analysis_GuaranteedDefs$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_internal_analysis_GuaranteedDefs$method$getGuaranteedDefs$68ecc6b5537a17ad(_jc_env *, struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_analysis_GuaranteedDefs$method_info$getGuaranteedDefs$68ecc6b5537a17ad;

// Virtual methods structure
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods {
	struct _jc_object	*(*getGuaranteedDefs$68ecc6b5537a17ad)(_jc_env *, struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vmethods	soot_shimple_internal_analysis_GuaranteedDefs;
};

// Vtype
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs {
	struct _jc_object	*unitToGuaranteedDefs;
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$refs {
    _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_refs	soot_shimple_internal_analysis_GuaranteedDefs;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_analysis_GuaranteedDefs$sub_nonrefs	soot_shimple_internal_analysis_GuaranteedDefs;
};

// Object instance structure
struct _jc_soot_shimple_internal_analysis_GuaranteedDefs$object {
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype	*vtype;
	_jc_soot_shimple_internal_analysis_GuaranteedDefs$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_analysis_GuaranteedDefs$vtype _jc_soot_shimple_internal_analysis_GuaranteedDefs$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_analysis_GuaranteedDefs, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_analysis_GuaranteedDefs$class_object;

#endif	/* _JC_soot_shimple_internal_analysis_GuaranteedDefs_H_ */
